==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/gfx/mod-gl/gl-background/gl-water/gl-water-setup.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#include "config.h"
#include "../../../gfx.h"
#include "gl-water.h"
#include "gl-water-internal.h"

/*
 * Low-level SDL initialisation.
 */
_MOD_GL_BACKGROUND_WATER_CONTEXT *
_mod_gl_background_water_init (MOD_GL_UTILS_CONTEXT * utils_context)
{
  _MOD_GL_BACKGROUND_WATER_CONTEXT *water_context = NULL;

  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("init background/water"));

  water_context =
    (_MOD_GL_BACKGROUND_WATER_CONTEXT *)
    LW6SYS_MALLOC (sizeof (_MOD_GL_BACKGROUND_WATER_CONTEXT));
  if (!water_context)
    {
      /*
       * No use to continue if this basic malloc fails...
       */
      exit (1);
    }

  memset (water_context, 0, sizeof (_MOD_GL_BACKGROUND_WATER_CONTEXT));


  if (!_mod_gl_background_water_load_data (utils_context, water_context))
    {
      LW6SYS_FREE (water_context);
      water_context = NULL;
    }

  return water_context;
}

void *
mod_gl_background_water_init (MOD_GL_UTILS_CONTEXT * utils_context)
{
  return (void *) _mod_gl_background_water_init (utils_context);
}

/*
 * Ends-up all SDL stuff.
 */
void
_mod_gl_background_water_quit (MOD_GL_UTILS_CONTEXT * utils_context,
			       _MOD_GL_BACKGROUND_WATER_CONTEXT *
			       water_context)
{
  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("quit background/water"));

  _mod_gl_background_water_unload_data (utils_context, water_context);
  LW6SYS_FREE (water_context);
}

void
mod_gl_background_water_quit (MOD_GL_UTILS_CONTEXT * utils_context,
			      void *water_context)
{
  _mod_gl_background_water_quit (utils_context,
				 (_MOD_GL_BACKGROUND_WATER_CONTEXT *)
				 water_context);
}

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/gfx/mod-gl/gl-background/gl-water/gl-water-setup.c <==
/*
Liquid War 6 is a unique multiplayer wargame.
Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.


Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
Contact author        : ufoot@ufoot.org
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#include "config.h"
#include "../../../gfx.h"
#include "gl-water.h"
#include "gl-water-internal.h"

/*
 * Low-level SDL initialisation.
 */
_MOD_GL_BACKGROUND_WATER_CONTEXT *
_mod_gl_background_water_init (MOD_GL_UTILS_CONTEXT * utils_context)
{
  _MOD_GL_BACKGROUND_WATER_CONTEXT *water_context = NULL;

  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("init background/water"));

  water_context =
    (_MOD_GL_BACKGROUND_WATER_CONTEXT *)
    LW6SYS_MALLOC (sizeof (_MOD_GL_BACKGROUND_WATER_CONTEXT));
  if (!water_context)
    {
      /*
       * No use to continue if this basic malloc fails...
       */
      exit (1);
    }

  memset (water_context, 0, sizeof (_MOD_GL_BACKGROUND_WATER_CONTEXT));


  if (!_mod_gl_background_water_load_data (utils_context, water_context))
    {
      LW6SYS_FREE (water_context);
      water_context = NULL;
    }

  return water_context;
}

void *
mod_gl_background_water_init (MOD_GL_UTILS_CONTEXT * utils_context)
{
  return (void *) _mod_gl_background_water_init (utils_context);
}

/*
 * Ends-up all SDL stuff.
 */
void
_mod_gl_background_water_quit (MOD_GL_UTILS_CONTEXT * utils_context,
			       _MOD_GL_BACKGROUND_WATER_CONTEXT *
			       water_context)
{
  lw6sys_log (LW6SYS_LOG_INFO, "gfx-mod-gl", _("quit background/water"));

  _mod_gl_background_water_unload_data (utils_context, water_context);
  LW6SYS_FREE (water_context);
}

void
mod_gl_background_water_quit (MOD_GL_UTILS_CONTEXT * utils_context,
			      void *water_context)
{
  _mod_gl_background_water_quit (utils_context,
				 (_MOD_GL_BACKGROUND_WATER_CONTEXT *)
				 water_context);
}
